Crate typesec_integrations

Crate typesec_integrations 

Provider integrations for using Typesec behind OAuth/OIDC systems.

This crate keeps external identity and authorization services at the edge of the system while preserving the core Typesec invariant: provider decisions become typed capabilities only through typesec_core::mint_capability.

Re-exports

pub use arcade::ArcadeToolAuthEngine;
pub use arcade::ArcadeToolAuthRequest;
pub use http::HttpClient;
pub use http::ReqwestHttpClient;
pub use jwt::JwtAuthenticator;
pub use jwt::JwtClaims;
pub use jwt::JwtClaimsEngine;
pub use jwt::OidcConfig;
pub use jwt::VerifiedSubject;
pub use workos::WorkOsFgaEngine;
pub use workos::WorkOsFgaRequest;
pub use workos::WorkOsResource;

Modules

arcade
Arcade-style tool authorization integration.
http
Small synchronous HTTP abstraction used by provider-backed policy engines.
jwt
JWT/OIDC authentication helpers and a fast claims-backed policy engine.
workos
WorkOS Fine-Grained Authorization integration.