Module arcade

Module arcade 

Arcade-style tool authorization integration.

Structs

ArcadeToolAuthEngine
Policy engine that checks whether a user has authorized an external tool.
ArcadeToolAuthRequest
Request body used to ask Arcade whether a tool is authorized for a user.