pub struct DidEnvelope {
pub id: String,
pub message_type: String,
pub from: Did,
pub to: Vec<Did>,
pub created_time: u64,
pub expires_time: u64,
pub body: DidMessageBody,
pub typedid: Option<TypeDidConversation>,
pub kid: String,
pub nonce: String,
pub ciphertext: String,
pub signature: String,
}Expand description
Encrypted DID message envelope.
Fields
id: StringMessage id.
message_type: StringMessage type URI.
from: DidSender DID.
to: Vec<Did>Recipient DIDs.
created_time: u64Creation time as unix seconds.
expires_time: u64Expiration time as unix seconds.
body: DidMessageBodyPolicy-visible message metadata.
typedid: Option<TypeDidConversation>Optional TypeDID conversation/profile metadata.
kid: StringKey id used for authentication.
nonce: StringHex-encoded nonce.
ciphertext: StringHex-encoded ciphertext.
signature: StringHex-encoded signature over the envelope signing input.
Implementations
Sourceimpl DidEnvelope
impl DidEnvelope
Sourcepub fn prompt(
id: impl Into<String>,
from: Did,
to: Did,
body: DidMessageBody,
plaintext: impl AsRef<[u8]>,
resolver: &dyn DidResolver,
key_store: &dyn DidKeyStore,
) -> Result<Self, DidError>
pub fn prompt( id: impl Into<String>, from: Did, to: Did, body: DidMessageBody, plaintext: impl AsRef<[u8]>, resolver: &dyn DidResolver, key_store: &dyn DidKeyStore, ) -> Result<Self, DidError>
Create an encrypted prompt envelope.
Sourcepub fn reply(
reply_did: Did,
from: Did,
to: Did,
binding: DidReplyBinding,
plaintext: impl AsRef<[u8]>,
resolver: &dyn DidResolver,
key_store: &dyn DidKeyStore,
) -> Result<Self, DidError>
pub fn reply( reply_did: Did, from: Did, to: Did, binding: DidReplyBinding, plaintext: impl AsRef<[u8]>, resolver: &dyn DidResolver, key_store: &dyn DidKeyStore, ) -> Result<Self, DidError>
Create an encrypted reply envelope bound to a verified prompt envelope.
Sourcepub fn typedid(
id: impl Into<String>,
from: Did,
to: Did,
body: DidMessageBody,
typedid: TypeDidConversation,
plaintext: impl AsRef<[u8]>,
resolver: &dyn DidResolver,
key_store: &dyn DidKeyStore,
) -> Result<Self, DidError>
pub fn typedid( id: impl Into<String>, from: Did, to: Did, body: DidMessageBody, typedid: TypeDidConversation, plaintext: impl AsRef<[u8]>, resolver: &dyn DidResolver, key_store: &dyn DidKeyStore, ) -> Result<Self, DidError>
Create an encrypted TypeDID agent-message envelope.
Sourcepub fn typedid_reply(
id: impl Into<String>,
from: Did,
to: Did,
request: &VerifiedTypeDidMessage,
plaintext: impl AsRef<[u8]>,
resolver: &dyn DidResolver,
key_store: &dyn DidKeyStore,
) -> Result<Self, DidError>
pub fn typedid_reply( id: impl Into<String>, from: Did, to: Did, request: &VerifiedTypeDidMessage, plaintext: impl AsRef<[u8]>, resolver: &dyn DidResolver, key_store: &dyn DidKeyStore, ) -> Result<Self, DidError>
Create an encrypted TypeDID reply envelope bound to a verified request.
Sourcepub fn reference(&self) -> DidMessageReference
pub fn reference(&self) -> DidMessageReference
Stable reference to this signed envelope for reply binding.