pub struct TypeDidConversation {
pub conversation_id: String,
pub mode: TypeDidMode,
pub profile: String,
pub protocol: String,
pub expires_at: Option<u64>,
}Expand description
TypeDID conversation metadata bound into the envelope signature.
Fields
conversation_id: StringStable task, session, room, or thread id from the outer protocol.
mode: TypeDidModeDelivery mode.
profile: StringNegotiated TypeDID profile id.
protocol: StringOuter protocol hint, such as a2a, acp, band, or https.
expires_at: Option<u64>Optional payload expiry copied from the negotiated profile or caller.
Implementations
Sourceimpl TypeDidConversation
impl TypeDidConversation
Sourcepub fn new(
conversation_id: impl Into<String>,
mode: TypeDidMode,
profile: impl Into<String>,
protocol: impl Into<String>,
) -> Self
pub fn new( conversation_id: impl Into<String>, mode: TypeDidMode, profile: impl Into<String>, protocol: impl Into<String>, ) -> Self
Construct TypeDID conversation metadata.
Sourcepub fn with_expires_at(self, expires_at: u64) -> Self
pub fn with_expires_at(self, expires_at: u64) -> Self
Attach an absolute unix-seconds expiry to this conversation metadata.