TypeDidProfile

Struct TypeDidProfile 

pub struct TypeDidProfile {
    pub id: String,
    pub did_methods: Vec<String>,
    pub signing: Vec<String>,
    pub key_agreement: Vec<String>,
    pub encryption: Vec<String>,
    pub transport_bindings: Vec<String>,
    pub modes: Vec<TypeDidMode>,
    pub max_payload_bytes: Option<usize>,
    pub required_claims: Vec<String>,
    pub policy_actions: Vec<String>,
    pub retention: Option<String>,
    pub audit: Option<String>,
}
A negotiable TypeDID security profile.

Fields

id: String

Stable profile id.

did_methods: Vec<String>

Supported DID methods, such as did:web or did:key.

signing: Vec<String>

Supported signing algorithms.

key_agreement: Vec<String>

Supported key-agreement algorithms.

encryption: Vec<String>

Supported encryption profiles.

transport_bindings: Vec<String>

Supported outer transport bindings.

modes: Vec<TypeDidMode>

Supported TypeDID send modes.

max_payload_bytes: Option<usize>

Optional maximum encrypted payload size.

required_claims: Vec<String>

Claims required by the remote boundary.

policy_actions: Vec<String>

Policy actions this profile is willing to carry.

retention: Option<String>

Retention posture advertised by the receiver.

audit: Option<String>

Audit posture advertised by the receiver.

Implementations

Source

impl TypeDidProfile

pub fn ed25519_x25519_chacha20() -> Self

Default local TypeDID profile backed by the built-in Ed25519/X25519 key store.

pub fn is_compatible_with( &self, remote: &Self, protocol: &str, mode: TypeDidMode, ) -> bool

Return true when this local profile can safely communicate with remote.

pub fn negotiate<'a>( local: &'a [Self], remote: &[Self], protocol: &str, mode: TypeDidMode, ) -> Result<&'a Self, DidError>

Select the first local profile compatible with the remote boundary.