Module http

Module http 

Small synchronous HTTP abstraction used by provider-backed policy engines.

Structs

RecordedRequest
Captured request made through RecordingHttpClient.
RecordingHttpClient
Static client that also records every request it receives.
ReqwestHttpClient
reqwest-backed implementation of HttpClient.
StaticHttpClient
Test helper that returns preconfigured responses for exact URLs.

Traits

HttpClient
Minimal HTTP client interface for JSON POST/GET calls.