Arcade-style tool authorization integration.
Structs
- Arcade
Tool Auth Engine - Policy engine that checks whether a user has authorized an external tool.
- Arcade
Tool Auth Request - Request body used to ask Arcade whether a tool is authorized for a user.