pub struct ArcadeToolAuthEngine { /* private fields */ }Expand description
Policy engine that checks whether a user has authorized an external tool.
The engine maps Typesec resource ids to Arcade tool names. A resource id may
either be present in the explicit mapping or already look like an Arcade tool
name such as Gmail.ListEmails.
Implementations