DidError

Enum DidError 

pub enum DidError {
Show 21 variants InvalidDid(String), Unresolved(String), MissingPrivateKey(String), MissingAuthentication, MissingKeyAgreement, MissingVerificationMethod(String), InvalidSignature, WrongRecipient(String), Expired, InvalidKey(String), InvalidNonce, EncryptionFailed, DecryptionFailed, KeyGen(String), Capability(SecureAccessError), InvalidHex, InvalidUtf8, Http(Box<dyn Error + Send + Sync>), MissingOllamaReply, MissingTypeDidMetadata, NoCompatibleTypeDidProfile,
}
DID integration errors.

Variants



InvalidDid(String)

DID syntax is invalid.



Unresolved(String)

DID could not be resolved.



MissingPrivateKey(String)

No private key is available for a local DID.



MissingAuthentication

DID document did not contain an authentication key.



MissingKeyAgreement

DID document did not contain a key agreement key.



MissingVerificationMethod(String)

Referenced verification method is absent.



InvalidSignature

Envelope signature did not verify.



WrongRecipient(String)

Envelope recipient does not match this gateway.



Expired

Envelope has expired.



InvalidKey(String)

Key material has the wrong size or encoding.



InvalidNonce

AEAD nonce must be exactly 12 bytes.



EncryptionFailed

Payload encryption failed.



DecryptionFailed

Payload decryption or authentication failed.



KeyGen(String)

Operating system RNG was unavailable.



Capability(SecureAccessError)

A typed capability did not cover the protected payload’s resource.



InvalidHex

Hex input is malformed.



InvalidUtf8

Decrypted payload is not UTF-8.



Http(Box<dyn Error + Send + Sync>)

HTTP request failed.



MissingOllamaReply

Ollama response did not contain an assistant message.



MissingTypeDidMetadata

A TypeDID envelope did not include TypeDID metadata.



NoCompatibleTypeDidProfile

Local and remote TypeDID profiles did not overlap.